@@ -18,7 +18,11 @@ class ApiKey:
         'user_id': None,     # int64 - User ID for the owner of this API Key.  May be blank for Site-wide API Keys.
     }
 
-    def __init__(self, attributes={}, options={}):
+    def __init__(self, attributes=None, options=None):
+        if not isinstance(attributes, dict):
+            attributes = {}
+        if not isinstance(options, dict):
+            options = {}
         self.set_attributes(attributes)
         self.options = options
 
@@ -33,7 +37,7 @@ class ApiKey:
     #   name - string - Internal name for the API Key.  For your use.
     #   expires_at - string - API Key expiration date
     #   permission_set - string - Permissions for this API Key.  Keys with the `desktop_app` permission set only have the ability to do the functions provided in our Desktop App (File and Share Link operations).  Additional permission sets may become available in the future, such as for a Site Admin to give a key with no administrator privileges.  If you have ideas for permission sets, please let us know.
-    def update(self, params = {}):
+    def update(self, params = None):
         if not isinstance(params, dict):
             params = {}
 
@@ -54,7 +58,7 @@ class ApiKey:
         response, _options = Api.send_request("PATCH", "/api_keys/{id}".format(id=params['id']), params, self.options)
         return response.data
 
-    def delete(self, params = {}):
+    def delete(self, params = None):
         if not isinstance(params, dict):
             params = {}
 
@@ -69,7 +73,7 @@ class ApiKey:
         response, _options = Api.send_request("DELETE", "/api_keys/{id}".format(id=params['id']), params, self.options)
         return response.data
 
-    def destroy(self, params = {}):
+    def destroy(self, params = None):
         self.delete(params)
 
     def save(self):
@@ -81,10 +85,8 @@ class ApiKey:
 
 # Parameters:
 #   user_id - int64 - User ID.  Provide a value of `0` to operate the current session's user.
-#   page - int64 - Current page number.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
-#   action - string - Deprecated: If set to `count` returns a count of matching records rather than the records themselves.
-#   cursor - string - Send cursor to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   sort_by - object - If set, sort records by the specified field in either 'asc' or 'desc' direction (e.g. sort_by[last_login_at]=desc). Valid fields are `deleted_at` and `expires_at`.
 #   filter - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `expires_at`.
 #   filter_gt - object - If set, return records where the specifiied field is greater than the supplied value. Valid fields are `expires_at`.
@@ -92,17 +94,13 @@ class ApiKey:
 #   filter_like - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `expires_at`.
 #   filter_lt - object - If set, return records where the specifiied field is less than the supplied value. Valid fields are `expires_at`.
 #   filter_lteq - object - If set, return records where the specifiied field is less than or equal to the supplied value. Valid fields are `expires_at`.
-def list(params = {}, options = {}):
+def list(params = None, options = None):
     if "user_id" in params and not isinstance(params["user_id"], int):
         raise InvalidParameterError("Bad parameter: user_id must be an int")
-    if "page" in params and not isinstance(params["page"], int):
-        raise InvalidParameterError("Bad parameter: page must be an int")
-    if "per_page" in params and not isinstance(params["per_page"], int):
-        raise InvalidParameterError("Bad parameter: per_page must be an int")
-    if "action" in params and not isinstance(params["action"], str):
-        raise InvalidParameterError("Bad parameter: action must be an str")
     if "cursor" in params and not isinstance(params["cursor"], str):
         raise InvalidParameterError("Bad parameter: cursor must be an str")
+    if "per_page" in params and not isinstance(params["per_page"], int):
+        raise InvalidParameterError("Bad parameter: per_page must be an int")
     if "sort_by" in params and not isinstance(params["sort_by"], dict):
         raise InvalidParameterError("Bad parameter: sort_by must be an dict")
     if "filter" in params and not isinstance(params["filter"], dict):
@@ -119,13 +117,13 @@ def list(params = {}, options = {}):
         raise InvalidParameterError("Bad parameter: filter_lteq must be an dict")
     return ListObj(ApiKey,"GET", "/api_keys", params, options)
 
-def all(params = {}, options = {}):
+def all(params = None, options = None):
     list(params, options)
 
 # Parameters:
 #   format - string
 #   api_key - object
-def find_current(params = {}, options = {}):
+def find_current(params = None, options = None):
     if "format" in params and not isinstance(params["format"], str):
         raise InvalidParameterError("Bad parameter: format must be an str")
     if "api_key" in params and not isinstance(params["api_key"], dict):
@@ -135,9 +133,11 @@ def find_current(params = {}, options = {}):
 
 # Parameters:
 #   id (required) - int64 - Api Key ID.
-def find(id, params = {}, options = {}):
+def find(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -146,7 +146,7 @@ def find(id, params = {}, options = {}):
     response, options = Api.send_request("GET", "/api_keys/{id}".format(id=params['id']), params, options)
     return ApiKey(response.data, options)
 
-def get(id, params = {}, options = {}):
+def get(id, params = None, options = None):
     find(id, params, options)
 
 # Parameters:
@@ -155,7 +155,7 @@ def get(id, params = {}, options = {}):
 #   expires_at - string - API Key expiration date
 #   permission_set - string - Permissions for this API Key.  Keys with the `desktop_app` permission set only have the ability to do the functions provided in our Desktop App (File and Share Link operations).  Additional permission sets may become available in the future, such as for a Site Admin to give a key with no administrator privileges.  If you have ideas for permission sets, please let us know.
 #   path - string - Folder path restriction for this api key.
-def create(params = {}, options = {}):
+def create(params = None, options = None):
     if "user_id" in params and not isinstance(params["user_id"], int):
         raise InvalidParameterError("Bad parameter: user_id must be an int")
     if "name" in params and not isinstance(params["name"], str):
@@ -173,7 +173,7 @@ def create(params = {}, options = {}):
 #   expires_at - string - API Key expiration date
 #   name - string - Internal name for the API Key.  For your use.
 #   permission_set - string - Permissions for this API Key.  Keys with the `desktop_app` permission set only have the ability to do the functions provided in our Desktop App (File and Share Link operations).  Additional permission sets may become available in the future, such as for a Site Admin to give a key with no administrator privileges.  If you have ideas for permission sets, please let us know.
-def update_current(params = {}, options = {}):
+def update_current(params = None, options = None):
     if "expires_at" in params and not isinstance(params["expires_at"], str):
         raise InvalidParameterError("Bad parameter: expires_at must be an str")
     if "name" in params and not isinstance(params["name"], str):
@@ -187,9 +187,11 @@ def update_current(params = {}, options = {}):
 #   name - string - Internal name for the API Key.  For your use.
 #   expires_at - string - API Key expiration date
 #   permission_set - string - Permissions for this API Key.  Keys with the `desktop_app` permission set only have the ability to do the functions provided in our Desktop App (File and Share Link operations).  Additional permission sets may become available in the future, such as for a Site Admin to give a key with no administrator privileges.  If you have ideas for permission sets, please let us know.
-def update(id, params = {}, options = {}):
+def update(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -207,7 +209,7 @@ def update(id, params = {}, options = {}):
 # Parameters:
 #   format - string
 #   api_key - object
-def delete_current(params = {}, options = {}):
+def delete_current(params = None, options = None):
     if "format" in params and not isinstance(params["format"], str):
         raise InvalidParameterError("Bad parameter: format must be an str")
     if "api_key" in params and not isinstance(params["api_key"], dict):
@@ -215,9 +217,11 @@ def delete_current(params = {}, options = {}):
     response, _options = Api.send_request("DELETE", "/api_key", params, options)
     return response.data
 
-def delete(id, params = {}, options = {}):
+def delete(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -226,7 +230,7 @@ def delete(id, params = {}, options = {}):
     response, _options = Api.send_request("DELETE", "/api_keys/{id}".format(id=params['id']), params, options)
     return response.data
 
-def destroy(id, params = {}, options = {}):
+def destroy(id, params = None, options = None):
     delete(id, params, options)
 
 def new(*args, **kwargs):
