@@ -13,7 +13,11 @@ class Behavior:
         'attachment_file': None,     # file - Certain behaviors may require a file, for instance, the "watermark" behavior requires a watermark image
     }
 
-    def __init__(self, attributes={}, options={}):
+    def __init__(self, attributes=None, options=None):
+        if not isinstance(attributes, dict):
+            attributes = {}
+        if not isinstance(options, dict):
+            options = {}
         self.set_attributes(attributes)
         self.options = options
 
@@ -29,7 +33,7 @@ class Behavior:
     #   attachment_file - file - Certain behaviors may require a file, for instance, the "watermark" behavior requires a watermark image
     #   behavior - string - Behavior type.
     #   path - string - Folder behaviors path.
-    def update(self, params = {}):
+    def update(self, params = None):
         if not isinstance(params, dict):
             params = {}
 
@@ -50,7 +54,7 @@ class Behavior:
         response, _options = Api.send_request("PATCH", "/behaviors/{id}".format(id=params['id']), params, self.options)
         return response.data
 
-    def delete(self, params = {}):
+    def delete(self, params = None):
         if not isinstance(params, dict):
             params = {}
 
@@ -65,7 +69,7 @@ class Behavior:
         response, _options = Api.send_request("DELETE", "/behaviors/{id}".format(id=params['id']), params, self.options)
         return response.data
 
-    def destroy(self, params = {}):
+    def destroy(self, params = None):
         self.delete(params)
 
     def save(self):
@@ -76,10 +80,8 @@ class Behavior:
             self.set_attributes(new_obj.get_attributes())
 
 # Parameters:
-#   page - int64 - Current page number.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
-#   action - string - Deprecated: If set to `count` returns a count of matching records rather than the records themselves.
-#   cursor - string - Send cursor to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   sort_by - object - If set, sort records by the specified field in either 'asc' or 'desc' direction (e.g. sort_by[last_login_at]=desc). Valid fields are `site_id` and `behavior`.
 #   filter - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `behavior`.
 #   filter_gt - object - If set, return records where the specifiied field is greater than the supplied value. Valid fields are `behavior`.
@@ -88,15 +90,11 @@ class Behavior:
 #   filter_lt - object - If set, return records where the specifiied field is less than the supplied value. Valid fields are `behavior`.
 #   filter_lteq - object - If set, return records where the specifiied field is less than or equal to the supplied value. Valid fields are `behavior`.
 #   behavior - string - If set, only shows folder behaviors matching this behavior type.
-def list(params = {}, options = {}):
-    if "page" in params and not isinstance(params["page"], int):
-        raise InvalidParameterError("Bad parameter: page must be an int")
-    if "per_page" in params and not isinstance(params["per_page"], int):
-        raise InvalidParameterError("Bad parameter: per_page must be an int")
-    if "action" in params and not isinstance(params["action"], str):
-        raise InvalidParameterError("Bad parameter: action must be an str")
+def list(params = None, options = None):
     if "cursor" in params and not isinstance(params["cursor"], str):
         raise InvalidParameterError("Bad parameter: cursor must be an str")
+    if "per_page" in params and not isinstance(params["per_page"], int):
+        raise InvalidParameterError("Bad parameter: per_page must be an int")
     if "sort_by" in params and not isinstance(params["sort_by"], dict):
         raise InvalidParameterError("Bad parameter: sort_by must be an dict")
     if "filter" in params and not isinstance(params["filter"], dict):
@@ -115,14 +113,16 @@ def list(params = {}, options = {}):
         raise InvalidParameterError("Bad parameter: behavior must be an str")
     return ListObj(Behavior,"GET", "/behaviors", params, options)
 
-def all(params = {}, options = {}):
+def all(params = None, options = None):
     list(params, options)
 
 # Parameters:
 #   id (required) - int64 - Behavior ID.
-def find(id, params = {}, options = {}):
+def find(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -131,14 +131,12 @@ def find(id, params = {}, options = {}):
     response, options = Api.send_request("GET", "/behaviors/{id}".format(id=params['id']), params, options)
     return Behavior(response.data, options)
 
-def get(id, params = {}, options = {}):
+def get(id, params = None, options = None):
     find(id, params, options)
 
 # Parameters:
-#   page - int64 - Current page number.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
-#   action - string - Deprecated: If set to `count` returns a count of matching records rather than the records themselves.
-#   cursor - string - Send cursor to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   sort_by - object - If set, sort records by the specified field in either 'asc' or 'desc' direction (e.g. sort_by[last_login_at]=desc). Valid fields are `site_id` and `behavior`.
 #   filter - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `behavior`.
 #   filter_gt - object - If set, return records where the specifiied field is greater than the supplied value. Valid fields are `behavior`.
@@ -149,18 +147,16 @@ def get(id, params = {}, options = {}):
 #   path (required) - string - Path to operate on.
 #   recursive - string - Show behaviors above this path?
 #   behavior - string - DEPRECATED: If set only shows folder behaviors matching this behavior type. Use `filter[behavior]` instead.
-def list_for(path, params = {}, options = {}):
+def list_for(path, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["path"] = path
-    if "page" in params and not isinstance(params["page"], int):
-        raise InvalidParameterError("Bad parameter: page must be an int")
-    if "per_page" in params and not isinstance(params["per_page"], int):
-        raise InvalidParameterError("Bad parameter: per_page must be an int")
-    if "action" in params and not isinstance(params["action"], str):
-        raise InvalidParameterError("Bad parameter: action must be an str")
     if "cursor" in params and not isinstance(params["cursor"], str):
         raise InvalidParameterError("Bad parameter: cursor must be an str")
+    if "per_page" in params and not isinstance(params["per_page"], int):
+        raise InvalidParameterError("Bad parameter: per_page must be an int")
     if "sort_by" in params and not isinstance(params["sort_by"], dict):
         raise InvalidParameterError("Bad parameter: sort_by must be an dict")
     if "filter" in params and not isinstance(params["filter"], dict):
@@ -190,7 +186,7 @@ def list_for(path, params = {}, options = {}):
 #   attachment_file - file - Certain behaviors may require a file, for instance, the "watermark" behavior requires a watermark image
 #   path (required) - string - Folder behaviors path.
 #   behavior (required) - string - Behavior type.
-def create(params = {}, options = {}):
+def create(params = None, options = None):
     if "value" in params and not isinstance(params["value"], str):
         raise InvalidParameterError("Bad parameter: value must be an str")
     if "path" in params and not isinstance(params["path"], str):
@@ -211,7 +207,7 @@ def create(params = {}, options = {}):
 #   headers - object - Additional request headers.
 #   body - object - Additional body parameters.
 #   action - string - action for test body
-def webhook_test(params = {}, options = {}):
+def webhook_test(params = None, options = None):
     if "url" in params and not isinstance(params["url"], str):
         raise InvalidParameterError("Bad parameter: url must be an str")
     if "method" in params and not isinstance(params["method"], str):
@@ -234,9 +230,11 @@ def webhook_test(params = {}, options = {}):
 #   attachment_file - file - Certain behaviors may require a file, for instance, the "watermark" behavior requires a watermark image
 #   behavior - string - Behavior type.
 #   path - string - Folder behaviors path.
-def update(id, params = {}, options = {}):
+def update(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], (str, int, dict)): 
         raise InvalidParameterError("Bad parameter: id must be one of str, int, dict")
@@ -251,9 +249,11 @@ def update(id, params = {}, options = {}):
     response, options = Api.send_request("PATCH", "/behaviors/{id}".format(id=params['id']), params, options)
     return Behavior(response.data, options)
 
-def delete(id, params = {}, options = {}):
+def delete(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -262,7 +262,7 @@ def delete(id, params = {}, options = {}):
     response, _options = Api.send_request("DELETE", "/behaviors/{id}".format(id=params['id']), params, options)
     return response.data
 
-def destroy(id, params = {}, options = {}):
+def destroy(id, params = None, options = None):
     delete(id, params, options)
 
 def new(*args, **kwargs):
