@@ -21,11 +21,16 @@ class Bundle:
         'username': None,     # string - Bundle creator username
         'clickwrap_id': None,     # int64 - ID of the clickwrap to use with this bundle.
         'inbox_id': None,     # int64 - ID of the associated inbox, if available.
+        'has_inbox': None,     # boolean - Does this bundle have an associated inbox?
         'paths': None,     # array - A list of paths in this bundle
         'password': None,     # string - Password for this bundle.
     }
 
-    def __init__(self, attributes={}, options={}):
+    def __init__(self, attributes=None, options=None):
+        if not isinstance(attributes, dict):
+            attributes = {}
+        if not isinstance(options, dict):
+            options = {}
         self.set_attributes(attributes)
         self.options = options
 
@@ -41,7 +46,8 @@ class Bundle:
     # Parameters:
     #   to (required) - array(string) - A list of email addresses to share this bundle with.
     #   note - string - Note to include in email.
-    def share(self, params = {}):
+    #   recipients - array(object) - A list of recipients to share this bundle with.
+    def share(self, params = None):
         if not isinstance(params, dict):
             params = {}
 
@@ -59,6 +65,8 @@ class Bundle:
             raise InvalidParameterError("Bad parameter: to must be an list")
         if "note" in params and not isinstance(params["note"], str):
             raise InvalidParameterError("Bad parameter: note must be an str")
+        if "recipients" in params and not isinstance(params["recipients"], list):
+            raise InvalidParameterError("Bad parameter: recipients must be an list")
         response, _options = Api.send_request("POST", "/bundles/{id}/share".format(id=params['id']), params, self.options)
         return response.data
 
@@ -73,7 +81,7 @@ class Bundle:
     #   note - string - Bundle internal note
     #   require_registration - boolean - Show a registration page that captures the downloader's name and email address?
     #   require_share_recipient - boolean - Only allow access to recipients who have explicitly received the share via an email sent through the Files.com UI?
-    def update(self, params = {}):
+    def update(self, params = None):
         if not isinstance(params, dict):
             params = {}
 
@@ -104,7 +112,7 @@ class Bundle:
         response, _options = Api.send_request("PATCH", "/bundles/{id}".format(id=params['id']), params, self.options)
         return response.data
 
-    def delete(self, params = {}):
+    def delete(self, params = None):
         if not isinstance(params, dict):
             params = {}
 
@@ -119,7 +127,7 @@ class Bundle:
         response, _options = Api.send_request("DELETE", "/bundles/{id}".format(id=params['id']), params, self.options)
         return response.data
 
-    def destroy(self, params = {}):
+    def destroy(self, params = None):
         self.delete(params)
 
     def save(self):
@@ -131,10 +139,8 @@ class Bundle:
 
 # Parameters:
 #   user_id - int64 - User ID.  Provide a value of `0` to operate the current session's user.
-#   page - int64 - Current page number.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
-#   action - string - Deprecated: If set to `count` returns a count of matching records rather than the records themselves.
-#   cursor - string - Send cursor to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   sort_by - object - If set, sort records by the specified field in either 'asc' or 'desc' direction (e.g. sort_by[last_login_at]=desc). Valid fields are `site_id`, `created_at` or `code`.
 #   filter - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `created_at`.
 #   filter_gt - object - If set, return records where the specifiied field is greater than the supplied value. Valid fields are `created_at`.
@@ -142,17 +148,13 @@ class Bundle:
 #   filter_like - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `created_at`.
 #   filter_lt - object - If set, return records where the specifiied field is less than the supplied value. Valid fields are `created_at`.
 #   filter_lteq - object - If set, return records where the specifiied field is less than or equal to the supplied value. Valid fields are `created_at`.
-def list(params = {}, options = {}):
+def list(params = None, options = None):
     if "user_id" in params and not isinstance(params["user_id"], int):
         raise InvalidParameterError("Bad parameter: user_id must be an int")
-    if "page" in params and not isinstance(params["page"], int):
-        raise InvalidParameterError("Bad parameter: page must be an int")
-    if "per_page" in params and not isinstance(params["per_page"], int):
-        raise InvalidParameterError("Bad parameter: per_page must be an int")
-    if "action" in params and not isinstance(params["action"], str):
-        raise InvalidParameterError("Bad parameter: action must be an str")
     if "cursor" in params and not isinstance(params["cursor"], str):
         raise InvalidParameterError("Bad parameter: cursor must be an str")
+    if "per_page" in params and not isinstance(params["per_page"], int):
+        raise InvalidParameterError("Bad parameter: per_page must be an int")
     if "sort_by" in params and not isinstance(params["sort_by"], dict):
         raise InvalidParameterError("Bad parameter: sort_by must be an dict")
     if "filter" in params and not isinstance(params["filter"], dict):
@@ -169,14 +171,16 @@ def list(params = {}, options = {}):
         raise InvalidParameterError("Bad parameter: filter_lteq must be an dict")
     return ListObj(Bundle,"GET", "/bundles", params, options)
 
-def all(params = {}, options = {}):
+def all(params = None, options = None):
     list(params, options)
 
 # Parameters:
 #   id (required) - int64 - Bundle ID.
-def find(id, params = {}, options = {}):
+def find(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -185,7 +189,7 @@ def find(id, params = {}, options = {}):
     response, options = Api.send_request("GET", "/bundles/{id}".format(id=params['id']), params, options)
     return Bundle(response.data, options)
 
-def get(id, params = {}, options = {}):
+def get(id, params = None, options = None):
     find(id, params, options)
 
 # Parameters:
@@ -201,7 +205,7 @@ def get(id, params = {}, options = {}):
 #   clickwrap_id - int64 - ID of the clickwrap to use with this bundle.
 #   inbox_id - int64 - ID of the associated inbox, if available.
 #   require_share_recipient - boolean - Only allow access to recipients who have explicitly received the share via an email sent through the Files.com UI?
-def create(params = {}, options = {}):
+def create(params = None, options = None):
     if "user_id" in params and not isinstance(params["user_id"], int):
         raise InvalidParameterError("Bad parameter: user_id must be an int")
     if "paths" in params and not isinstance(params["paths"], list):
@@ -232,9 +236,12 @@ def create(params = {}, options = {}):
 # Parameters:
 #   to (required) - array(string) - A list of email addresses to share this bundle with.
 #   note - string - Note to include in email.
-def share(id, params = {}, options = {}):
+#   recipients - array(object) - A list of recipients to share this bundle with.
+def share(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -242,6 +249,8 @@ def share(id, params = {}, options = {}):
         raise InvalidParameterError("Bad parameter: to must be an list")
     if "note" in params and not isinstance(params["note"], str):
         raise InvalidParameterError("Bad parameter: note must be an str")
+    if "recipients" in params and not isinstance(params["recipients"], list):
+        raise InvalidParameterError("Bad parameter: recipients must be an list")
     if "id" not in params:
         raise MissingParameterError("Parameter missing: id")
     if "to" not in params:
@@ -260,9 +269,11 @@ def share(id, params = {}, options = {}):
 #   note - string - Bundle internal note
 #   require_registration - boolean - Show a registration page that captures the downloader's name and email address?
 #   require_share_recipient - boolean - Only allow access to recipients who have explicitly received the share via an email sent through the Files.com UI?
-def update(id, params = {}, options = {}):
+def update(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -287,9 +298,11 @@ def update(id, params = {}, options = {}):
     response, options = Api.send_request("PATCH", "/bundles/{id}".format(id=params['id']), params, options)
     return Bundle(response.data, options)
 
-def delete(id, params = {}, options = {}):
+def delete(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -298,7 +311,7 @@ def delete(id, params = {}, options = {}):
     response, _options = Api.send_request("DELETE", "/bundles/{id}".format(id=params['id']), params, options)
     return response.data
 
-def destroy(id, params = {}, options = {}):
+def destroy(id, params = None, options = None):
     delete(id, params, options)
 
 def new(*args, **kwargs):
