@@ -5,15 +5,19 @@ from files_sdk.exceptions import InvalidParameterError, MissingParameterError, N
 
 class Clickwrap:
     default_attributes = {
+        'id': None,     # int64 - Clickwrap ID
         'name': None,     # string - Name of the Clickwrap agreement (used when selecting from multiple Clickwrap agreements.)
         'body': None,     # string - Body text of Clickwrap (supports Markdown formatting).
         'use_with_users': None,     # string - Use this Clickwrap for User Registrations?  Note: This only applies to User Registrations where the User is invited to your Files.com site using an E-Mail invitation process where they then set their own password.
         'use_with_bundles': None,     # string - Use this Clickwrap for Bundles?
         'use_with_inboxes': None,     # string - Use this Clickwrap for Inboxes?
-        'id': None,     # int64 - Clickwrap ID.
     }
 
-    def __init__(self, attributes={}, options={}):
+    def __init__(self, attributes=None, options=None):
+        if not isinstance(attributes, dict):
+            attributes = {}
+        if not isinstance(options, dict):
+            options = {}
         self.set_attributes(attributes)
         self.options = options
 
@@ -30,7 +34,7 @@ class Clickwrap:
     #   use_with_bundles - string - Use this Clickwrap for Bundles?
     #   use_with_inboxes - string - Use this Clickwrap for Inboxes?
     #   use_with_users - string - Use this Clickwrap for User Registrations?  Note: This only applies to User Registrations where the User is invited to your Files.com site using an E-Mail invitation process where they then set their own password.
-    def update(self, params = {}):
+    def update(self, params = None):
         if not isinstance(params, dict):
             params = {}
 
@@ -55,7 +59,7 @@ class Clickwrap:
         response, _options = Api.send_request("PATCH", "/clickwraps/{id}".format(id=params['id']), params, self.options)
         return response.data
 
-    def delete(self, params = {}):
+    def delete(self, params = None):
         if not isinstance(params, dict):
             params = {}
 
@@ -70,7 +74,7 @@ class Clickwrap:
         response, _options = Api.send_request("DELETE", "/clickwraps/{id}".format(id=params['id']), params, self.options)
         return response.data
 
-    def destroy(self, params = {}):
+    def destroy(self, params = None):
         self.delete(params)
 
     def save(self):
@@ -81,29 +85,25 @@ class Clickwrap:
             self.set_attributes(new_obj.get_attributes())
 
 # Parameters:
-#   page - int64 - Current page number.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
-#   action - string - Deprecated: If set to `count` returns a count of matching records rather than the records themselves.
-#   cursor - string - Send cursor to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
-def list(params = {}, options = {}):
-    if "page" in params and not isinstance(params["page"], int):
-        raise InvalidParameterError("Bad parameter: page must be an int")
-    if "per_page" in params and not isinstance(params["per_page"], int):
-        raise InvalidParameterError("Bad parameter: per_page must be an int")
-    if "action" in params and not isinstance(params["action"], str):
-        raise InvalidParameterError("Bad parameter: action must be an str")
+def list(params = None, options = None):
     if "cursor" in params and not isinstance(params["cursor"], str):
         raise InvalidParameterError("Bad parameter: cursor must be an str")
+    if "per_page" in params and not isinstance(params["per_page"], int):
+        raise InvalidParameterError("Bad parameter: per_page must be an int")
     return ListObj(Clickwrap,"GET", "/clickwraps", params, options)
 
-def all(params = {}, options = {}):
+def all(params = None, options = None):
     list(params, options)
 
 # Parameters:
 #   id (required) - int64 - Clickwrap ID.
-def find(id, params = {}, options = {}):
+def find(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -112,7 +112,7 @@ def find(id, params = {}, options = {}):
     response, options = Api.send_request("GET", "/clickwraps/{id}".format(id=params['id']), params, options)
     return Clickwrap(response.data, options)
 
-def get(id, params = {}, options = {}):
+def get(id, params = None, options = None):
     find(id, params, options)
 
 # Parameters:
@@ -121,7 +121,7 @@ def get(id, params = {}, options = {}):
 #   use_with_bundles - string - Use this Clickwrap for Bundles?
 #   use_with_inboxes - string - Use this Clickwrap for Inboxes?
 #   use_with_users - string - Use this Clickwrap for User Registrations?  Note: This only applies to User Registrations where the User is invited to your Files.com site using an E-Mail invitation process where they then set their own password.
-def create(params = {}, options = {}):
+def create(params = None, options = None):
     if "name" in params and not isinstance(params["name"], str):
         raise InvalidParameterError("Bad parameter: name must be an str")
     if "body" in params and not isinstance(params["body"], str):
@@ -141,9 +141,11 @@ def create(params = {}, options = {}):
 #   use_with_bundles - string - Use this Clickwrap for Bundles?
 #   use_with_inboxes - string - Use this Clickwrap for Inboxes?
 #   use_with_users - string - Use this Clickwrap for User Registrations?  Note: This only applies to User Registrations where the User is invited to your Files.com site using an E-Mail invitation process where they then set their own password.
-def update(id, params = {}, options = {}):
+def update(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -162,9 +164,11 @@ def update(id, params = {}, options = {}):
     response, options = Api.send_request("PATCH", "/clickwraps/{id}".format(id=params['id']), params, options)
     return Clickwrap(response.data, options)
 
-def delete(id, params = {}, options = {}):
+def delete(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -173,7 +177,7 @@ def delete(id, params = {}, options = {}):
     response, _options = Api.send_request("DELETE", "/clickwraps/{id}".format(id=params['id']), params, options)
     return response.data
 
-def destroy(id, params = {}, options = {}):
+def destroy(id, params = None, options = None):
     delete(id, params, options)
 
 def new(*args, **kwargs):
