@@ -29,6 +29,7 @@ class User:
         'last_protocol_cipher': None,     # string - The last protocol and cipher used
         'lockout_expires': None,     # date-time - Time in the future that the user will no longer be locked out if applicable
         'name': None,     # string - User's full name
+        'company': None,     # string - User's company
         'notes': None,     # string - Any internal notes on the user
         'notification_daily_send_time': None,     # int64 - Hour of the day at which daily notifications should be sent. Can be in range 0 to 23
         'office_integration_enabled': None,     # boolean - Enable integration with Office for the web?
@@ -36,7 +37,8 @@ class User:
         'password_validity_days': None,     # int64 - Number of days to allow user to use the same password
         'public_keys_count': None,     # int64 - Number of public keys associated with this user
         'receive_admin_alerts': None,     # boolean - Should the user receive admin alerts such a certificate expiration notifications and overages?
-        'require_2fa': None,     # boolean - Is 2fa required to sign in?
+        'require_2fa': None,     # string - 2FA required setting
+        'active_2fa': None,     # boolean - Is 2fa active for the user?
         'require_password_change': None,     # boolean - Is a password change required upon next user login?
         'restapi_permission': None,     # boolean - Can this user access the REST API?
         'self_managed': None,     # boolean - Does this user manage it's own credentials or is it a shared/bot user?
@@ -61,7 +63,11 @@ class User:
         'announcements_read': None,     # boolean - Signifies that the user has read all the announcements in the UI.
     }
 
-    def __init__(self, attributes={}, options={}):
+    def __init__(self, attributes=None, options=None):
+        if not isinstance(attributes, dict):
+            attributes = {}
+        if not isinstance(options, dict):
+            options = {}
         self.set_attributes(attributes)
         self.options = options
 
@@ -73,7 +79,7 @@ class User:
         return {k: getattr(self, k, None) for k in User.default_attributes if getattr(self, k, None) is not None}
 
     # Unlock user who has been locked out due to failed logins
-    def unlock(self, params = {}):
+    def unlock(self, params = None):
         if not isinstance(params, dict):
             params = {}
 
@@ -89,7 +95,7 @@ class User:
         return response.data
 
     # Resend user welcome email
-    def resend_welcome_email(self, params = {}):
+    def resend_welcome_email(self, params = None):
         if not isinstance(params, dict):
             params = {}
 
@@ -105,7 +111,7 @@ class User:
         return response.data
 
     # Trigger 2FA Reset process for user who has lost access to their existing 2FA methods
-    def user_2fa_reset(self, params = {}):
+    def user_2fa_reset(self, params = None):
         if not isinstance(params, dict):
             params = {}
 
@@ -146,6 +152,7 @@ class User:
     #   language - string - Preferred language
     #   notification_daily_send_time - int64 - Hour of the day at which daily notifications should be sent. Can be in range 0 to 23
     #   name - string - User's full name
+    #   company - string - User's company
     #   notes - string - Any internal notes on the user
     #   office_integration_enabled - boolean - Enable integration with Office for the web?
     #   password_validity_days - int64 - Number of days to allow user to use the same password
@@ -159,10 +166,11 @@ class User:
     #   ssl_required - string - SSL required setting
     #   sso_strategy_id - int64 - SSO (Single Sign On) strategy ID for the user, if applicable.
     #   subscribe_to_newsletter - boolean - Is the user subscribed to the newsletter?
+    #   require_2fa - string - 2FA required setting
     #   time_zone - string - User time zone
     #   user_root - string - Root folder for FTP (and optionally SFTP if the appropriate site-wide setting is set.)  Note that this is not used for API, Desktop, or Web interface.
     #   username - string - User's username
-    def update(self, params = {}):
+    def update(self, params = None):
         if not isinstance(params, dict):
             params = {}
 
@@ -204,6 +212,8 @@ class User:
             raise InvalidParameterError("Bad parameter: notification_daily_send_time must be an int")
         if "name" in params and not isinstance(params["name"], str):
             raise InvalidParameterError("Bad parameter: name must be an str")
+        if "company" in params and not isinstance(params["company"], str):
+            raise InvalidParameterError("Bad parameter: company must be an str")
         if "notes" in params and not isinstance(params["notes"], str):
             raise InvalidParameterError("Bad parameter: notes must be an str")
         if "password_validity_days" in params and not isinstance(params["password_validity_days"], int):
@@ -212,6 +222,8 @@ class User:
             raise InvalidParameterError("Bad parameter: ssl_required must be an str")
         if "sso_strategy_id" in params and not isinstance(params["sso_strategy_id"], int):
             raise InvalidParameterError("Bad parameter: sso_strategy_id must be an int")
+        if "require_2fa" in params and not isinstance(params["require_2fa"], str):
+            raise InvalidParameterError("Bad parameter: require_2fa must be an str")
         if "time_zone" in params and not isinstance(params["time_zone"], str):
             raise InvalidParameterError("Bad parameter: time_zone must be an str")
         if "user_root" in params and not isinstance(params["user_root"], str):
@@ -221,7 +233,7 @@ class User:
         response, _options = Api.send_request("PATCH", "/users/{id}".format(id=params['id']), params, self.options)
         return response.data
 
-    def delete(self, params = {}):
+    def delete(self, params = None):
         if not isinstance(params, dict):
             params = {}
 
@@ -236,7 +248,7 @@ class User:
         response, _options = Api.send_request("DELETE", "/users/{id}".format(id=params['id']), params, self.options)
         return response.data
 
-    def destroy(self, params = {}):
+    def destroy(self, params = None):
         self.delete(params)
 
     def save(self):
@@ -247,17 +259,15 @@ class User:
             self.set_attributes(new_obj.get_attributes())
 
 # Parameters:
-#   page - int64 - Current page number.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
-#   action - string - Deprecated: If set to `count` returns a count of matching records rather than the records themselves.
-#   cursor - string - Send cursor to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
-#   sort_by - object - If set, sort records by the specified field in either 'asc' or 'desc' direction (e.g. sort_by[last_login_at]=desc). Valid fields are `active`, `master_admin`, `site_id`, `authenticate_until`, `email`, `last_desktop_login_at`, `last_login_at`, `username`, `notes`, `site_admin`, `receive_admin_alerts`, `allowed_ips`, `password_validity_days`, `ssl_required` or `not_site_admin`.
-#   filter - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `username`, `email`, `notes`, `site_admin`, `allowed_ips`, `password_validity_days`, `ssl_required`, `last_login_at`, `authenticate_until` or `not_site_admin`.
-#   filter_gt - object - If set, return records where the specifiied field is greater than the supplied value. Valid fields are `username`, `email`, `notes`, `site_admin`, `allowed_ips`, `password_validity_days`, `ssl_required`, `last_login_at`, `authenticate_until` or `not_site_admin`.
-#   filter_gteq - object - If set, return records where the specifiied field is greater than or equal to the supplied value. Valid fields are `username`, `email`, `notes`, `site_admin`, `allowed_ips`, `password_validity_days`, `ssl_required`, `last_login_at`, `authenticate_until` or `not_site_admin`.
-#   filter_like - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `username`, `email`, `notes`, `site_admin`, `allowed_ips`, `password_validity_days`, `ssl_required`, `last_login_at`, `authenticate_until` or `not_site_admin`.
-#   filter_lt - object - If set, return records where the specifiied field is less than the supplied value. Valid fields are `username`, `email`, `notes`, `site_admin`, `allowed_ips`, `password_validity_days`, `ssl_required`, `last_login_at`, `authenticate_until` or `not_site_admin`.
-#   filter_lteq - object - If set, return records where the specifiied field is less than or equal to the supplied value. Valid fields are `username`, `email`, `notes`, `site_admin`, `allowed_ips`, `password_validity_days`, `ssl_required`, `last_login_at`, `authenticate_until` or `not_site_admin`.
+#   sort_by - object - If set, sort records by the specified field in either 'asc' or 'desc' direction (e.g. sort_by[last_login_at]=desc). Valid fields are `active`, `master_admin`, `site_id`, `authenticate_until`, `email`, `last_desktop_login_at`, `last_login_at`, `username`, `company`, `name`, `notes`, `site_admin`, `receive_admin_alerts`, `allowed_ips`, `password_validity_days`, `ssl_required` or `not_site_admin`.
+#   filter - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `username`, `email`, `company`, `notes`, `site_admin`, `allowed_ips`, `password_validity_days`, `ssl_required`, `last_login_at`, `authenticate_until` or `not_site_admin`.
+#   filter_gt - object - If set, return records where the specifiied field is greater than the supplied value. Valid fields are `username`, `email`, `company`, `notes`, `site_admin`, `allowed_ips`, `password_validity_days`, `ssl_required`, `last_login_at`, `authenticate_until` or `not_site_admin`.
+#   filter_gteq - object - If set, return records where the specifiied field is greater than or equal to the supplied value. Valid fields are `username`, `email`, `company`, `notes`, `site_admin`, `allowed_ips`, `password_validity_days`, `ssl_required`, `last_login_at`, `authenticate_until` or `not_site_admin`.
+#   filter_like - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `username`, `email`, `company`, `notes`, `site_admin`, `allowed_ips`, `password_validity_days`, `ssl_required`, `last_login_at`, `authenticate_until` or `not_site_admin`.
+#   filter_lt - object - If set, return records where the specifiied field is less than the supplied value. Valid fields are `username`, `email`, `company`, `notes`, `site_admin`, `allowed_ips`, `password_validity_days`, `ssl_required`, `last_login_at`, `authenticate_until` or `not_site_admin`.
+#   filter_lteq - object - If set, return records where the specifiied field is less than or equal to the supplied value. Valid fields are `username`, `email`, `company`, `notes`, `site_admin`, `allowed_ips`, `password_validity_days`, `ssl_required`, `last_login_at`, `authenticate_until` or `not_site_admin`.
 #   ids - string - comma-separated list of User IDs
 #   q[username] - string - List users matching username.
 #   q[email] - string - List users matching email.
@@ -267,15 +277,11 @@ class User:
 #   q[password_validity_days] - string - If set, list only users with overridden password validity days setting.
 #   q[ssl_required] - string - If set, list only users with overridden SSL required setting.
 #   search - string - Searches for partial matches of name, username, or email.
-def list(params = {}, options = {}):
-    if "page" in params and not isinstance(params["page"], int):
-        raise InvalidParameterError("Bad parameter: page must be an int")
-    if "per_page" in params and not isinstance(params["per_page"], int):
-        raise InvalidParameterError("Bad parameter: per_page must be an int")
-    if "action" in params and not isinstance(params["action"], str):
-        raise InvalidParameterError("Bad parameter: action must be an str")
+def list(params = None, options = None):
     if "cursor" in params and not isinstance(params["cursor"], str):
         raise InvalidParameterError("Bad parameter: cursor must be an str")
+    if "per_page" in params and not isinstance(params["per_page"], int):
+        raise InvalidParameterError("Bad parameter: per_page must be an int")
     if "sort_by" in params and not isinstance(params["sort_by"], dict):
         raise InvalidParameterError("Bad parameter: sort_by must be an dict")
     if "filter" in params and not isinstance(params["filter"], dict):
@@ -296,14 +302,16 @@ def list(params = {}, options = {}):
         raise InvalidParameterError("Bad parameter: search must be an str")
     return ListObj(User,"GET", "/users", params, options)
 
-def all(params = {}, options = {}):
+def all(params = None, options = None):
     list(params, options)
 
 # Parameters:
 #   id (required) - int64 - User ID.
-def find(id, params = {}, options = {}):
+def find(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -312,7 +320,7 @@ def find(id, params = {}, options = {}):
     response, options = Api.send_request("GET", "/users/{id}".format(id=params['id']), params, options)
     return User(response.data, options)
 
-def get(id, params = {}, options = {}):
+def get(id, params = None, options = None):
     find(id, params, options)
 
 # Parameters:
@@ -341,6 +349,7 @@ def get(id, params = {}, options = {}):
 #   language - string - Preferred language
 #   notification_daily_send_time - int64 - Hour of the day at which daily notifications should be sent. Can be in range 0 to 23
 #   name - string - User's full name
+#   company - string - User's company
 #   notes - string - Any internal notes on the user
 #   office_integration_enabled - boolean - Enable integration with Office for the web?
 #   password_validity_days - int64 - Number of days to allow user to use the same password
@@ -354,10 +363,11 @@ def get(id, params = {}, options = {}):
 #   ssl_required - string - SSL required setting
 #   sso_strategy_id - int64 - SSO (Single Sign On) strategy ID for the user, if applicable.
 #   subscribe_to_newsletter - boolean - Is the user subscribed to the newsletter?
+#   require_2fa - string - 2FA required setting
 #   time_zone - string - User time zone
 #   user_root - string - Root folder for FTP (and optionally SFTP if the appropriate site-wide setting is set.)  Note that this is not used for API, Desktop, or Web interface.
 #   username - string - User's username
-def create(params = {}, options = {}):
+def create(params = None, options = None):
     if "change_password" in params and not isinstance(params["change_password"], str):
         raise InvalidParameterError("Bad parameter: change_password must be an str")
     if "change_password_confirmation" in params and not isinstance(params["change_password_confirmation"], str):
@@ -388,6 +398,8 @@ def create(params = {}, options = {}):
         raise InvalidParameterError("Bad parameter: notification_daily_send_time must be an int")
     if "name" in params and not isinstance(params["name"], str):
         raise InvalidParameterError("Bad parameter: name must be an str")
+    if "company" in params and not isinstance(params["company"], str):
+        raise InvalidParameterError("Bad parameter: company must be an str")
     if "notes" in params and not isinstance(params["notes"], str):
         raise InvalidParameterError("Bad parameter: notes must be an str")
     if "password_validity_days" in params and not isinstance(params["password_validity_days"], int):
@@ -396,6 +408,8 @@ def create(params = {}, options = {}):
         raise InvalidParameterError("Bad parameter: ssl_required must be an str")
     if "sso_strategy_id" in params and not isinstance(params["sso_strategy_id"], int):
         raise InvalidParameterError("Bad parameter: sso_strategy_id must be an int")
+    if "require_2fa" in params and not isinstance(params["require_2fa"], str):
+        raise InvalidParameterError("Bad parameter: require_2fa must be an str")
     if "time_zone" in params and not isinstance(params["time_zone"], str):
         raise InvalidParameterError("Bad parameter: time_zone must be an str")
     if "user_root" in params and not isinstance(params["user_root"], str):
@@ -406,9 +420,11 @@ def create(params = {}, options = {}):
     return User(response.data, options)
 
 # Unlock user who has been locked out due to failed logins
-def unlock(id, params = {}, options = {}):
+def unlock(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -418,9 +434,11 @@ def unlock(id, params = {}, options = {}):
     return response.data
 
 # Resend user welcome email
-def resend_welcome_email(id, params = {}, options = {}):
+def resend_welcome_email(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -430,9 +448,11 @@ def resend_welcome_email(id, params = {}, options = {}):
     return response.data
 
 # Trigger 2FA Reset process for user who has lost access to their existing 2FA methods
-def user_2fa_reset(id, params = {}, options = {}):
+def user_2fa_reset(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -467,6 +487,7 @@ def user_2fa_reset(id, params = {}, options = {}):
 #   language - string - Preferred language
 #   notification_daily_send_time - int64 - Hour of the day at which daily notifications should be sent. Can be in range 0 to 23
 #   name - string - User's full name
+#   company - string - User's company
 #   notes - string - Any internal notes on the user
 #   office_integration_enabled - boolean - Enable integration with Office for the web?
 #   password_validity_days - int64 - Number of days to allow user to use the same password
@@ -480,12 +501,15 @@ def user_2fa_reset(id, params = {}, options = {}):
 #   ssl_required - string - SSL required setting
 #   sso_strategy_id - int64 - SSO (Single Sign On) strategy ID for the user, if applicable.
 #   subscribe_to_newsletter - boolean - Is the user subscribed to the newsletter?
+#   require_2fa - string - 2FA required setting
 #   time_zone - string - User time zone
 #   user_root - string - Root folder for FTP (and optionally SFTP if the appropriate site-wide setting is set.)  Note that this is not used for API, Desktop, or Web interface.
 #   username - string - User's username
-def update(id, params = {}, options = {}):
+def update(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -519,6 +543,8 @@ def update(id, params = {}, options = {}):
         raise InvalidParameterError("Bad parameter: notification_daily_send_time must be an int")
     if "name" in params and not isinstance(params["name"], str):
         raise InvalidParameterError("Bad parameter: name must be an str")
+    if "company" in params and not isinstance(params["company"], str):
+        raise InvalidParameterError("Bad parameter: company must be an str")
     if "notes" in params and not isinstance(params["notes"], str):
         raise InvalidParameterError("Bad parameter: notes must be an str")
     if "password_validity_days" in params and not isinstance(params["password_validity_days"], int):
@@ -527,6 +553,8 @@ def update(id, params = {}, options = {}):
         raise InvalidParameterError("Bad parameter: ssl_required must be an str")
     if "sso_strategy_id" in params and not isinstance(params["sso_strategy_id"], int):
         raise InvalidParameterError("Bad parameter: sso_strategy_id must be an int")
+    if "require_2fa" in params and not isinstance(params["require_2fa"], str):
+        raise InvalidParameterError("Bad parameter: require_2fa must be an str")
     if "time_zone" in params and not isinstance(params["time_zone"], str):
         raise InvalidParameterError("Bad parameter: time_zone must be an str")
     if "user_root" in params and not isinstance(params["user_root"], str):
@@ -538,9 +566,11 @@ def update(id, params = {}, options = {}):
     response, options = Api.send_request("PATCH", "/users/{id}".format(id=params['id']), params, options)
     return User(response.data, options)
 
-def delete(id, params = {}, options = {}):
+def delete(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -549,7 +579,7 @@ def delete(id, params = {}, options = {}):
     response, _options = Api.send_request("DELETE", "/users/{id}".format(id=params['id']), params, options)
     return response.data
 
-def destroy(id, params = {}, options = {}):
+def destroy(id, params = None, options = None):
     delete(id, params, options)
 
 def new(*args, **kwargs):
